@@ -2,12 +2,13 @@
 Date         : 2023-11-02 12:44:48
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-11-13 12:47:53
+LastEditTime : 2023-11-13 15:42:46
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\graph\__init__.py
 Copyright (c) 2023 by BDFD, All Rights Reserved. 
 '''
 
-from ._data_analysis_graph import discrete_feature_graph, top_correlation
+from ._data_analysis_graph import top_correlation
 from ._data_mining_graph import missing_value_analysis
+from ._linear_regression_type_graph import discrete_feature_graph
\ No newline at end of file
